translate.storage.xml_extract.unit_tree.XPathTree

Package translate :: Package storage :: Package xml_extract :: Module unit_tree :: Class XPathTree |
[hide private]
[frames] | no frames]

# Class XPathTree

source code

Instance Methods | [hide private]
__init__(self, unit=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__eq__(self, other) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, unit=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Decorators: `@accepts(Self(), IsOneOf(base.TranslationUnit, type(None)))` Overrides: object.__init__ (inherited documentation)